import { defineConfig, dynamicImport } from 'umi';

const CompressionWebpackPlugin = require('compression-webpack-plugin');
const prodGzipList = ['js', 'css'];

const packageFile = JSON.parse(fs.readFileSync("./package.json"));

export default defineConfig({
  // 使用npm远程cnd地址
  // publicPath: 'https://cdn.jsdelivr.net/npm/umi-test-project@latest/dist/',

  // 使用oss远程cnd地址 (还缺少node脚本同步oss没写)
  publicPath: `https://gstor-default-workspace-cn-shanghai-c218770b.oss-accelerate.aliyuncs.com/${packageFile.name}/${packageFile.version}/dist/`,

  // 拆包配置
  chainWebpack(config) {
    config.merge({
      optimization: {
        minimize: true,
        splitChunks: {
          chunks: 'async',
          minSize: 30000,
          minChunks: 2,
          automaticNameDelimiter: '.',
          cacheGroups: {
            vendors: {
              // 基本框架
              name: 'vendors',
              test: /^.*node_modules[\\/](?!react|react-dom|antd|lodash).*$/,
              chunks: 'all',
              priority: 10,
            },
            'async-commons': {
              // 其余异步加载包
              chunks: 'async',
              minChunks: 2,
              name: 'async-commons',
              priority: 9,
            },
            commons: {
              // 其余同步加载包
              chunks: 'all',
              minChunks: 2,
              name: 'commons',
              priority: 8,
            },
          },
        },
      },
    });
    //过滤掉momnet的那些不使用的国际化文件
    config
      .plugin('replace')
      .use(require('webpack').ContextReplacementPlugin)
      .tap(() => {
        return [/moment[/\\]locale$/, /zh-cn/];
      });
    if (process.env.NODE_ENV === 'production') {
      // 生产模式开启
      config.plugin('compression-webpack-plugin').use(
        new CompressionWebpackPlugin({
          // filename: 文件名称，这里我们不设置，让它保持和未压缩的文件同一个名称
          algorithm: 'gzip', // 指定生成gzip格式
          test: new RegExp('\\.(' + prodGzipList.join('|') + ')$'), // 匹配哪些格式文件需要压缩
          threshold: 1024, //10240对超过10k的数据进行压缩
          minRatio: 0.6, // 压缩比例，值为0 ~ 1
        }),
      );
    }
  },
});
