import { defineConfig, dynamicImport } from 'umi';

import pageRoutes from './router.config';
import alias from './alias';
import theme from './theme';

//* 设置环境
var define;
var environment = process.env.PROJECT_ENV || 'localhost';
if (environment == 'localhost')
  define = require('./environments/localhost').default;
if (environment == 'dev') define = require('./environments/dev').default;
if (environment == 'test') define = require('./environments/test').default;

console.log('--------------------------------------------');
console.log(`--------------当前环境是${environment}----------------`);
console.log('--------------------------------------------');
console.log(define);

export default defineConfig({
  // 插件配置
  // plugins: ['@umijs/plugin-qiankun'],

  // 设置编译模式
  nodeModulesTransform: {
    type: 'none',
    exclude: [],
  },

  // 静态化 一个路由文件对应一个html文件 (为了百度爬虫以及谷歌爬虫)
  exportStatic: {},

  //按需加载
  dynamicImport: {},

  // dva
  dva: {},

  // antd
  antd: {},

  //路由配置
  routes: pageRoutes,

  // 国际化配置
  locale: {
    antd: true, // 是否启用antd的<LocaleProvider />  ------由之前的enbale改为 antd
    default: 'zh-CN', //默认语言 zh-CN
    baseNavigator: true, //为true时，用navigator.language的值作为默认语言
    baseSeparator: '-', //语言之间的分隔符
  },

  //多环境配置
  define: define,

  //别名文件的指向
  alias: alias,

  // less变量
  theme: theme,

  //缓存穿透
  hash: true,

  // 配置需要兼容的浏览器最低版本
  targets: {
    ie: 11,
  },

  // 忽略 moment 的 locale 文件，用于减少尺寸。
  ignoreMomentLocale: true,

  resolve: {
    alias: {
      react: '//localhost:8000/react@17.js',
      'react-dom': '//localhost:8000/react-dom@17.js',
    },
  },

});
